@@ -8,6 +8,8 @@ import random
 from base64 import b64decode
 import textwrap
 
+from azure.core.exceptions import HttpResponseError
+from azure.mgmt.core.tools import resource_id, parse_resource_id
 import azure.mgmt.redhatopenshift.models as openshiftcluster
 
 from azure.cli.core.commands.client_factory import get_mgmt_service_client
@@ -27,8 +29,6 @@ from azure.cli.command_modules.role import GraphError
 
 from knack.log import get_logger
 
-from msrestazure.azure_exceptions import CloudError
-from msrestazure.tools import resource_id, parse_resource_id
 from msrest.exceptions import HttpOperationError
 
 from tabulate import tabulate
@@ -237,7 +237,7 @@ def validate(cmd,  # pylint: disable=too-many-locals,too-many-statements
         # Get cluster resources we need to assign permissions on, sort to ensure the same order of operations
         resources = {ROLE_NETWORK_CONTRIBUTOR: sorted(get_cluster_network_resources(cmd.cli_ctx, cluster, True)),
                      ROLE_READER: sorted(get_disk_encryption_resources(cluster))}
-    except (CloudError, HttpOperationError) as e:
+    except (HttpResponseError, HttpOperationError) as e:
         logger.error(e.message)
         raise
 
@@ -343,7 +343,7 @@ def aro_delete(cmd, client, resource_group_name, resource_name, no_wait=False):
 
     try:
         oc = client.open_shift_clusters.get(resource_group_name, resource_name)
-    except CloudError as e:
+    except HttpResponseError as e:
         if e.status_code == 404:
             raise ResourceNotFoundError(e.message) from e
         logger.info(e.message)
@@ -619,7 +619,7 @@ def ensure_resource_permissions(cli_ctx, oc, fail, sp_obj_ids):
         # Get cluster resources we need to assign permissions on, sort to ensure the same order of operations
         resources = {ROLE_NETWORK_CONTRIBUTOR: sorted(get_cluster_network_resources(cli_ctx, oc, fail)),
                      ROLE_READER: sorted(get_disk_encryption_resources(oc))}
-    except (CloudError, HttpOperationError) as e:
+    except (HttpResponseError, HttpOperationError) as e:
         if fail:
             logger.error(e.message)
             raise
@@ -634,7 +634,7 @@ def ensure_resource_permissions(cli_ctx, oc, fail, sp_obj_ids):
                 resource_contributor_exists = True
                 try:
                     resource_contributor_exists = has_role_assignment_on_resource(cli_ctx, resource, sp_id, role)
-                except CloudError as e:
+                except HttpResponseError as e:
                     if fail:
                         logger.error(e.message)
                         raise
