@@ -63,6 +63,12 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
             actions=[LocalContextAction.GET, LocalContextAction.SET],
             scopes=['mysql flexible-server']))
 
+    database_port_arg_type = CLIArgumentType(
+        type=int,
+        options_list=['--database-port'],
+        help='The port of the database. Default value is 3306'
+    )
+
     tier_arg_type = CLIArgumentType(
         options_list=['--tier'],
         help='Compute tier of the server. Accepted values: Burstable, GeneralPurpose, MemoryOptimized '
@@ -116,6 +122,18 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         help='Enable or disable accelerated logs. Only support for Business Critical tier. Default value is Enabled.'
     )
 
+    storage_redundancy_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['LocalRedundancy', 'ZoneRedundancy']),
+        options_list=['--storage-redundancy'],
+        help='Enable local redundancy or zone redundancy. Zone redundancy only supports Business Critical tier.'
+    )
+
+    maintenance_policy_patch_strategy_arg_type = CLIArgumentType(
+        arg_type=get_enum_type(['Regular', 'VirtualCanary']),
+        options_list=['--maintenance-policy-patch-strategy', '--patch-strategy'],
+        help='The patch strategy of maintenance policy. Accepted values: Regular, VirtualCanary. Default value is Regular.'
+    )
+
     yes_arg_type = CLIArgumentType(
         options_list=['--yes', '-y'],
         action='store_true',
@@ -321,7 +339,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('iops', arg_type=iops_arg_type)
         c.argument('auto_grow', default='Enabled', arg_type=auto_grow_arg_type)
         c.argument('auto_scale_iops', default='Disabled', arg_type=auto_scale_iops_arg_type)
-        c.argument('accelerated_logs', default='Disabled', arg_type=accelerated_logs_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
         c.argument('backup_retention', default=7, arg_type=mysql_backup_retention_arg_type)
         c.argument('backup_byok_identity', arg_type=backup_identity_arg_type)
         c.argument('backup_byok_key', arg_type=backup_key_arg_type)
@@ -335,6 +353,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('public_access', arg_type=public_access_create_arg_type)
         c.argument('vnet', arg_type=vnet_arg_type)
         c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
@@ -342,6 +361,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tags', tags_type)
         c.argument('standby_availability_zone', arg_type=standby_availability_zone_arg_type)
         c.argument('database_name', arg_type=database_name_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
+        c.argument('maintenance_policy_patch_strategy', arg_type=maintenance_policy_patch_strategy_arg_type)
         c.argument('yes', arg_type=yes_arg_type)
 
     with self.argument_context('mysql flexible-server import create') as c:
@@ -391,6 +412,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('vnet_address_prefix', arg_type=vnet_address_prefix_arg_type)
         c.argument('subnet', arg_type=subnet_arg_type)
         c.argument('subnet_address_prefix', arg_type=subnet_address_prefix_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('private_dns_zone_arguments', private_dns_zone_arguments_arg_type)
         c.argument('zone', arg_type=zone_arg_type)
         c.argument('tags', tags_type)
@@ -399,9 +421,10 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tier', arg_type=tier_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
-        c.argument('accelerated_logs', default='Disabled', arg_type=accelerated_logs_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
         c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access. ')
 
     with self.argument_context('mysql flexible-server geo-restore') as c:
@@ -420,7 +443,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('tier', arg_type=tier_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('auto_grow', arg_type=auto_grow_arg_type)
-        c.argument('accelerated_logs', default='Disabled', arg_type=accelerated_logs_arg_type)
+        c.argument('accelerated_logs', arg_type=accelerated_logs_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
         c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']), help='Determines the public access. ')
@@ -448,6 +472,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('backup_byok_key', arg_type=backup_key_arg_type)
         c.argument('disable_data_encryption', arg_type=disable_data_encryption_arg_type)
         c.argument('public_access', arg_type=public_access_update_arg_type)
+        c.argument('maintenance_policy_patch_strategy', arg_type=maintenance_policy_patch_strategy_arg_type)
 
     with self.argument_context('mysql flexible-server upgrade') as c:
         c.argument('version', arg_type=mysql_version_upgrade_arg_type)
@@ -548,6 +573,8 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         c.argument('sku_name', arg_type=sku_name_arg_type)
         c.argument('storage_gb', arg_type=storage_gb_arg_type)
         c.argument('iops', arg_type=iops_arg_type)
+        c.argument('storage_redundancy', arg_type=storage_redundancy_arg_type)
+        c.argument('database_port', arg_type=database_port_arg_type)
         c.argument('backup_retention', arg_type=mysql_backup_retention_arg_type)
         c.argument('geo_redundant_backup', arg_type=geo_redundant_backup_arg_type)
 
