@@ -16,13 +16,14 @@ from azure.cli.core.commands.parameters import (
     get_three_state_flag)
 from azure.cli.command_modules.rdbms.validators import configuration_value_validator, validate_subnet, \
     tls_validator, public_access_validator, maintenance_window_validator, ip_address_validator, \
-    retention_validator, firewall_rule_name_validator, validate_identity, validate_byok_identity, validate_identities, \
-    virtual_endpoint_name_validator, node_count_validator
+    retention_validator, validate_identity, validate_byok_identity, validate_identities, \
+    virtual_endpoint_name_validator, node_count_validator, postgres_firewall_rule_name_validator
 from azure.cli.core.local_context import LocalContextAttribute, LocalContextAction
 
 from .randomname.generate import generate_username
 from ._flexible_server_util import get_current_time
 from argcomplete.completers import FilesCompleter
+from ._util import get_index_tuning_settings_map
 
 
 def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-locals
@@ -687,6 +688,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('public_access', options_list=['--public-access'], arg_type=get_enum_type(['Enabled', 'Disabled']),
                            help='Determines the public access. ')
             elif command_group == 'postgres':
+                c.argument('restore_point_in_time', arg_type=restore_point_in_time_arg_type)
                 c.argument('geo_redundant_backup', default='Disabled', arg_type=geo_redundant_backup_arg_type)
                 c.argument('byok_key', arg_type=key_arg_type)
                 c.argument('byok_identity', arg_type=identity_arg_type)
@@ -795,7 +797,7 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
         for scope in ['create', 'delete', 'show', 'update']:
             argument_context_string = '{} flexible-server firewall-rule {}'.format(command_group, scope)
             with self.argument_context(argument_context_string) as c:
-                c.argument('firewall_rule_name', id_part='child_name_1', options_list=['--rule-name', '-r'], validator=firewall_rule_name_validator,
+                c.argument('firewall_rule_name', id_part='child_name_1', options_list=['--rule-name', '-r'], validator=postgres_firewall_rule_name_validator,
                            help='The name of the firewall rule. If name is omitted, default name will be chosen for firewall name. The firewall rule name can only contain 0-9, a-z, A-Z, \'-\' and \'_\'. Additionally, the name of the firewall rule must be at least 3 characters and no more than 128 characters in length. ')
                 c.argument('end_ip_address', options_list=['--end-ip-address'], validator=ip_address_validator,
                            help='The end IP address of the firewall rule. Must be IPv4 format. Use value \'0.0.0.0\' to represent all Azure-internal IP addresses. ')
@@ -1033,6 +1035,37 @@ def load_arguments(self, _):    # pylint: disable=too-many-statements, too-many-
                 c.argument('resource_group_name', arg_type=resource_group_name_type)
                 c.argument('server_name', options_list=['--server-name', '-s'], id_part='name', arg_type=server_name_arg_type, required=False)
 
+        # index tuning
+        if command_group == 'postgres':
+            for scope in ['update', 'show', 'list-settings', 'show-settings', 'set-settings', 'list-recommendations']:
+                argument_context_string = '{} flexible-server index-tuning {}'.format(command_group, scope)
+                with self.argument_context(argument_context_string) as c:
+                    c.argument('server_name', options_list=['--server-name', '-s'], arg_type=server_name_arg_type)
+
+            with self.argument_context('{} flexible-server index-tuning update'.format(command_group)) as c:
+                c.argument('index_tuning_enabled',
+                           options_list=['--enabled'],
+                           required=True,
+                           help='Enable or disable index tuning feature.',
+                           arg_type=get_enum_type(['True', 'False']))
+
+            with self.argument_context('{} flexible-server index-tuning list-recommendations'.format(command_group)) as c:
+                c.argument('recommendation_type',
+                           options_list=['--recommendation-type', '-r'],
+                           help='Retrieve recommendations based on type.',
+                           arg_type=get_enum_type(['CreateIndex', 'DropIndex']))
+
+            for scope in ['show-settings', 'set-settings']:
+                argument_context_string = '{} flexible-server index-tuning {}'.format(command_group, scope)
+                with self.argument_context(argument_context_string) as c:
+                    c.argument('setting_name', options_list=['--name', '-n'], required=True,
+                               arg_type=get_enum_type(get_index_tuning_settings_map().keys()),
+                               help='The name of the tuning setting.')
+
+            with self.argument_context('{} flexible-server index-tuning set-settings'.format(command_group)) as c:
+                c.argument('value', options_list=['--value', '-v'],
+                           help='Value of the tuning setting.')
+
         # GTID
         if command_group == 'mysql':
             with self.argument_context('{} flexible-server gtid reset'.format(command_group)) as c:
