@@ -27,16 +27,18 @@ from ._client_factory import cf_postgres_flexible_firewall_rules, get_postgresql
     cf_postgres_flexible_db, cf_postgres_check_resource_availability, cf_postgres_flexible_servers, \
     cf_postgres_check_resource_availability_with_location, \
     cf_postgres_flexible_private_dns_zone_suffix_operations, \
-    cf_postgres_flexible_private_endpoint_connections
+    cf_postgres_flexible_private_endpoint_connections, \
+    cf_postgres_flexible_tuning_options
 from ._flexible_server_util import generate_missing_parameters, resolve_poller, \
     generate_password, parse_maintenance_window, get_current_time, build_identity_and_data_encryption, \
     _is_resource_name, get_tenant_id, get_case_insensitive_key_value, get_enum_value_true_false
 from ._flexible_server_location_capabilities_util import get_postgres_location_capability_info
+from ._util import get_index_tuning_settings_map
 from .flexible_server_custom_common import create_firewall_rule
 from .flexible_server_virtual_network import prepare_private_network, prepare_private_dns_zone, prepare_public_network
 from .validators import pg_arguments_validator, validate_server_name, validate_and_format_restore_point_in_time, \
     validate_postgres_replica, validate_georestore_network, pg_byok_validator, validate_migration_runtime_server, \
-    validate_resource_group, check_resource_group, validate_citus_cluster, cluster_byok_validator
+    validate_resource_group, check_resource_group, validate_citus_cluster, cluster_byok_validator, validate_backup_name
 
 logger = get_logger(__name__)
 DEFAULT_DB_NAME = 'flexibleserverdb'
@@ -233,12 +235,10 @@ def flexible_server_restore(cmd, client,
             logging_name='PostgreSQL', command_group='postgres', server_client=client, location=location)
         validate_server_name(db_context, server_name, 'Microsoft.DBforPostgreSQL/flexibleServers')
 
-        instance = client.get(id_parts['resource_group'], id_parts['name'])
-
-        cluster_byok_validator(byok_identity, byok_key, backup_byok_identity, backup_byok_key, geo_redundant_backup, instance)
+        cluster_byok_validator(byok_identity, byok_key, backup_byok_identity, backup_byok_key, geo_redundant_backup, source_server_object)
         pg_byok_validator(byok_identity, byok_key, backup_byok_identity, backup_byok_key, geo_redundant_backup)
 
-        storage = postgresql_flexibleservers.models.Storage(type=storage_type if instance.storage.type != "PremiumV2_LRS" else None)
+        storage = postgresql_flexibleservers.models.Storage(type=storage_type if source_server_object.storage.type != "PremiumV2_LRS" else None)
 
         parameters = postgresql_flexibleservers.models.Server(
             location=location,
@@ -362,6 +362,10 @@ def flexible_server_update_custom_func(cmd, client, instance,
     if instance.storage.type == "PremiumV2_LRS":
         instance.storage.tier = None
 
+        if sku_name or storage_gb:
+            logger.warning("You are changing the compute and/or storage size of the server. "
+                           "The server will be restarted for this operation and you will see a short downtime.")
+
         if iops:
             instance.storage.iops = iops
 
@@ -483,23 +487,29 @@ def flexible_server_postgresql_get(cmd, resource_group_name, server_name):
 
 def flexible_parameter_update(client, server_name, configuration_name, resource_group_name, source=None, value=None):
     validate_resource_group(resource_group_name)
-    if source is None and value is None:
-        # update the command with system default
-        try:
-            parameter = client.get(resource_group_name, server_name, configuration_name)
-            value = parameter.default_value  # reset value to default
+    parameter_value = value
+    parameter_source = source
+    try:
+        # validate configuration name
+        parameter = client.get(resource_group_name, server_name, configuration_name)
 
-            # this should be 'system-default' but there is currently a bug in PG, so keeping as what it is for now
+        # update the command with system default
+        if parameter_value is None and parameter_source is None:
+            parameter_value = parameter.default_value  # reset value to default
+
+            # this should be 'system-default' but there is currently a bug in PG
             # this will reset source to be 'system-default' anyway
-            source = parameter.source
-        except HttpResponseError as e:
+            parameter_source = "user-override"
+        elif parameter_source is None:
+            parameter_source = "user-override"
+    except HttpResponseError as e:
+        if parameter_value is None and parameter_source is None:
             raise CLIError('Unable to get default parameter value: {}.'.format(str(e)))
-    elif source is None:
-        source = "user-override"
+        raise CLIError(str(e))
 
     parameters = postgresql_flexibleservers.models.Configuration(
-        value=value,
-        source=source
+        value=parameter_value,
+        source=parameter_source
     )
 
     return client.begin_update(resource_group_name, server_name, configuration_name, parameters)
@@ -615,7 +625,7 @@ def flexible_replica_create(cmd, client, resource_group_name, source_server, rep
 def flexible_server_georestore(cmd, client, resource_group_name, server_name, source_server, location, zone=None,
                                vnet=None, vnet_address_prefix=None, subnet=None, subnet_address_prefix=None,
                                private_dns_zone_arguments=None, geo_redundant_backup=None, no_wait=False, yes=False,
-                               byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None):
+                               byok_identity=None, byok_key=None, backup_byok_identity=None, backup_byok_key=None, restore_point_in_time=None):
     validate_resource_group(resource_group_name)
 
     server_name = server_name.lower()
@@ -632,6 +642,8 @@ def flexible_server_georestore(cmd, client, resource_group_name, server_name, so
     else:
         source_server_id = source_server
 
+    restore_point_in_time = validate_and_format_restore_point_in_time(restore_point_in_time)
+
     try:
         id_parts = parse_resource_id(source_server_id)
         validate_citus_cluster(cmd, id_parts['resource_group'], id_parts['name'])
@@ -659,7 +671,7 @@ def flexible_server_georestore(cmd, client, resource_group_name, server_name, so
     storage = postgresql_flexibleservers.models.Storage(type=None)
 
     parameters = postgresql_flexibleservers.models.Server(
-        point_in_time_utc=get_current_time(),
+        point_in_time_utc=restore_point_in_time,
         location=location,
         source_server_resource_id=source_server_id,
         create_mode="GeoRestore",
@@ -915,21 +927,36 @@ def flexible_server_identity_update(cmd, client, resource_group_name, server_nam
     validate_resource_group(resource_group_name)
     validate_citus_cluster(cmd, resource_group_name, server_name)
 
-    identity_type = 'None'
-    if system_assigned.lower() == 'enabled':
-        identity_type = 'SystemAssigned'
-    else:
-        server = client.get(resource_group_name, server_name)
-        identity_type = 'UserAssigned' if (server and server.identity and server.identity.type and 'UserAssigned' in server.identity.type) else 'None'
+    server = client.get(resource_group_name, server_name)
+    identity_type = server.identity.type if (server and server.identity and server.identity.type) else 'None'
 
-    if identity_type == 'UserAssigned':
+    if system_assigned.lower() == 'enabled':
+        # user wants to enable system-assigned identity
+        if identity_type == 'None':
+            # if user-assigned identity is not enabled, then enable system-assigned identity
+            identity_type = 'SystemAssigned'
+        elif identity_type == 'UserAssigned':
+            # if user-assigned identity is enabled, then enable both system-assigned and user-assigned identity
+            identity_type = 'SystemAssigned,UserAssigned'
+    else:
+        if server.data_encryption.type == 'AzureKeyVault':
+            # if data encryption is enabled, then system-assigned identity cannot be disabled
+            raise CLIError("Disabling system-assigned identity isn't supported on servers configured to use customer managed keys for data encryption.")
+        if identity_type == 'SystemAssigned,UserAssigned':
+            # if both system-assigned and user-assigned identity is enabled, then disable system-assigned identity
+            identity_type = 'UserAssigned'
+        elif identity_type == 'SystemAssigned':
+            # if only system-assigned identity is enabled, then disable system-assigned identity
+            identity_type = 'None'
+
+    if identity_type == 'UserAssigned' or identity_type == 'SystemAssigned,UserAssigned':
         identities_map = {}
         for identity in server.identity.user_assigned_identities:
             identities_map[identity] = {}
         parameters = {
             'identity': postgresql_flexibleservers.models.UserAssignedIdentity(
                 user_assigned_identities=identities_map,
-                type="UserAssigned")}
+                type=identity_type)}
     else:
         parameters = {
             'identity': postgresql_flexibleservers.models.UserAssignedIdentity(
@@ -950,6 +977,16 @@ def flexible_server_identity_assign(cmd, client, resource_group_name, server_nam
     validate_resource_group(resource_group_name)
     validate_citus_cluster(cmd, resource_group_name, server_name)
 
+    server = client.get(resource_group_name, server_name)
+    identity_type = server.identity.type if (server and server.identity and server.identity.type) else 'None'
+
+    if identity_type == 'SystemAssigned':
+        # if system-assigned identity is enabled, then enable both system
+        identity_type = 'SystemAssigned,UserAssigned'
+    elif identity_type == 'None':
+        # if system-assigned identity is not enabled, then enable user-assigned identity
+        identity_type = 'UserAssigned'
+
     identities_map = {}
     for identity in identities:
         identities_map[identity] = {}
@@ -957,7 +994,7 @@ def flexible_server_identity_assign(cmd, client, resource_group_name, server_nam
     parameters = {
         'identity': postgresql_flexibleservers.models.UserAssignedIdentity(
             user_assigned_identities=identities_map,
-            type="UserAssigned")}
+            type=identity_type)}
 
     result = resolve_poller(
         client.begin_update(
@@ -1397,6 +1434,7 @@ def virtual_endpoint_update_func(cmd, client, resource_group_name, server_name,
 
 def backup_create_func(client, resource_group_name, server_name, backup_name):
     validate_resource_group(resource_group_name)
+    validate_backup_name(backup_name)
 
     return client.begin_create(
         resource_group_name,
@@ -1438,7 +1476,7 @@ def backup_delete_func(client, resource_group_name, server_name, backup_name, ye
 
     if not yes:
         user_confirmation(
-            "Are you sure you want to delete the backup '{0}' in resource group '{1}'".format(backup_name, resource_group_name), yes=yes)
+            "Are you sure you want to delete the backup '{0}' in server '{1}'".format(backup_name, server_name), yes=yes)
 
     return client.begin_delete(
         resource_group_name,
@@ -1485,12 +1523,17 @@ def flexible_server_fabric_mirroring_start(cmd, client, resource_group_name, ser
     validate_resource_group(resource_group_name)
     validate_citus_cluster(cmd, resource_group_name, server_name)
     flexible_servers_client = cf_postgres_flexible_servers(cmd.cli_ctx, '_')
+    server = flexible_servers_client.get(resource_group_name, server_name)
+
+    if server.high_availability.mode != "Disabled":
+        # disable fabric mirroring on HA server
+        raise CLIError("Fabric mirroring is not supported on servers with high availability enabled.")
 
     databases = ','.join(database_names[0].split())
     user_confirmation("Are you sure you want to prepare and enable your server" +
                       " '{0}' in resource group '{1}' for mirroring of databases '{2}'.".format(server_name, resource_group_name, databases) +
                       " This requires restart.", yes=yes)
-    server = flexible_servers_client.get(resource_group_name, server_name)
+
     if (server.identity is None or 'SystemAssigned' not in server.identity.type):
         logger.warning('Enabling system assigned managed identity on the server.')
         flexible_server_identity_update(cmd, flexible_servers_client, resource_group_name, server_name, 'Enabled')
@@ -1512,6 +1555,14 @@ def flexible_server_fabric_mirroring_start(cmd, client, resource_group_name, ser
 def flexible_server_fabric_mirroring_stop(cmd, client, resource_group_name, server_name, yes=False):
     validate_resource_group(resource_group_name)
     validate_citus_cluster(cmd, resource_group_name, server_name)
+
+    flexible_servers_client = cf_postgres_flexible_servers(cmd.cli_ctx, '_')
+    server = flexible_servers_client.get(resource_group_name, server_name)
+
+    if server.high_availability.mode != "Disabled":
+        # disable fabric mirroring on HA server
+        raise CLIError("Fabric mirroring is not supported on servers with high availability enabled.")
+
     user_confirmation("Are you sure you want to disable mirroring for server '{0}' in resource group '{1}'".format(server_name, resource_group_name), yes=yes)
 
     configuration_name = "azure.fabric_mirror_enabled"
@@ -1526,6 +1577,14 @@ def flexible_server_fabric_mirroring_stop(cmd, client, resource_group_name, serv
 def flexible_server_fabric_mirroring_update_databases(cmd, client, resource_group_name, server_name, database_names, yes=False):
     validate_resource_group(resource_group_name)
     validate_citus_cluster(cmd, resource_group_name, server_name)
+
+    flexible_servers_client = cf_postgres_flexible_servers(cmd.cli_ctx, '_')
+    server = flexible_servers_client.get(resource_group_name, server_name)
+
+    if server.high_availability.mode != "Disabled":
+        # disable fabric mirroring on HA server
+        raise CLIError("Fabric mirroring is not supported on servers with high availability enabled.")
+
     databases = ','.join(database_names[0].split())
     user_confirmation("Are you sure for server '{0}' in resource group '{1}' you want to update the databases being mirrored to be '{2}'"
                       .format(server_name, resource_group_name, databases), yes=yes)
@@ -1549,6 +1608,91 @@ def _update_parameters(cmd, client, server_name, configuration_name, resource_gr
         client.begin_update(resource_group_name, server_name, configuration_name, parameters), cmd.cli_ctx, 'PostgreSQL Parameter update')
 
 
+def index_tuning_update(cmd, client, resource_group_name, server_name, index_tuning_enabled):
+    validate_resource_group(resource_group_name)
+    source = "user-override"
+
+    if index_tuning_enabled == "True":
+        subscription = get_subscription_id(cmd.cli_ctx)
+        postgres_source_client = get_postgresql_flexible_management_client(cmd.cli_ctx, subscription)
+        source_server_object = postgres_source_client.servers.get(resource_group_name, server_name)
+        location = ''.join(source_server_object.location.lower().split())
+        list_location_capability_info = get_postgres_location_capability_info(cmd, location)
+        index_tuning_supported = list_location_capability_info['index_tuning_supported']
+        if not index_tuning_supported:
+            raise CLIError("Index tuning is not supported for the server.")
+
+        logger.warning("Enabling index tuning for the server.")
+        configuration_name = "index_tuning.mode"
+        value = "report"
+        _update_parameters(cmd, client, server_name, configuration_name, resource_group_name, source, value)
+        configuration_name = "pg_qs.query_capture_mode"
+        query_capture_mode_configuration = client.get(resource_group_name, server_name, configuration_name)
+
+        if query_capture_mode_configuration.value.lower() == "none":
+            value = "all"
+            _update_parameters(cmd, client, server_name, configuration_name, resource_group_name, source, value)
+        logger.warning("Index tuning is enabled for the server.")
+    else:
+        logger.warning("Disabling index tuning for the server.")
+        configuration_name = "index_tuning.mode"
+        value = "off"
+        _update_parameters(cmd, client, server_name, configuration_name, resource_group_name, source, value)
+        logger.warning("Index tuning is disabled for the server.")
+
+
+def index_tuning_show(client, resource_group_name, server_name):
+    validate_resource_group(resource_group_name)
+    index_tuning_configuration = client.get(resource_group_name, server_name, "index_tuning.mode")
+    query_capture_mode_configuration = client.get(resource_group_name, server_name, "pg_qs.query_capture_mode")
+
+    if index_tuning_configuration.value.lower() == "report" and query_capture_mode_configuration.value.lower() != "none":
+        logger.warning("Index tuning is enabled for the server.")
+    else:
+        logger.warning("Index tuning is disabled for the server.")
+
+
+def index_tuning_settings_list(cmd, client, resource_group_name, server_name):
+    validate_resource_group(resource_group_name)
+    index_tuning_configurations_map_values = get_index_tuning_settings_map().values()
+    configurations_list = client.list_by_server(resource_group_name, server_name)
+
+    # Filter the list based on the values in the dictionary
+    index_tuning_settings = [setting for setting in configurations_list if setting.name in index_tuning_configurations_map_values]
+
+    return index_tuning_settings
+
+
+def index_tuning_settings_get(cmd, client, resource_group_name, server_name, setting_name):
+    validate_resource_group(resource_group_name)
+    index_tuning_configurations_map = get_index_tuning_settings_map()
+    index_tuning_configuration_name = index_tuning_configurations_map[setting_name]
+
+    return client.get(
+        resource_group_name=resource_group_name,
+        server_name=server_name,
+        configuration_name=index_tuning_configuration_name)
+
+
+def index_tuning_settings_set(client, resource_group_name, server_name, setting_name, value=None):
+    source = "user-override" if value else None
+    tuning_settings = get_index_tuning_settings_map()
+    configuration_name = tuning_settings[setting_name]
+    return flexible_parameter_update(client, server_name, configuration_name, resource_group_name, source, value)
+
+
+def recommendations_list(cmd, resource_group_name, server_name, recommendation_type=None):
+    validate_resource_group(resource_group_name)
+    tuning_options_client = cf_postgres_flexible_tuning_options(cmd.cli_ctx, None)
+
+    return tuning_options_client.list_recommendations(
+        resource_group_name=resource_group_name,
+        server_name=server_name,
+        tuning_option="index",
+        recommendation_type=recommendation_type
+    )
+
+
 def _update_private_endpoint_connection_status(cmd, client, resource_group_name, server_name,
                                                private_endpoint_connection_name, is_approved=True, description=None):  # pylint: disable=unused-argument
     validate_resource_group(resource_group_name)
